#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# __about__.py

"""PyEMD metadata"""

__title__ = 'pyemd'
__version__ = '0.5.1'
__description__ = ("A Python wrapper for Ofir Pele and Michael Werman's "
                   "implementation of the Earth Mover's Distance.")
__author__ = 'Will Mayner'
__author_email__ = 'wmayner@gmail.com'
__author_website__ = 'http://willmayner.com'
__license__ = 'MIT'
__copyright__ = 'Copyright (c) 2014-2017 Will Mayner'
__url__ = 'http://github.com/wmayner/pyemd'

__all__ = ['__title__', '__version__', '__description__', '__author__',
           '__author_email__', '__author_website__', '__license__',
           '__copyright__', '__url__']
